summaryrefslogtreecommitdiffstats
path: root/klaptopdaemon/battery.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'klaptopdaemon/battery.cpp')
-rw-r--r--klaptopdaemon/battery.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/klaptopdaemon/battery.cpp b/klaptopdaemon/battery.cpp
index 2d62ca7..5e2c279 100644
--- a/klaptopdaemon/battery.cpp
+++ b/klaptopdaemon/battery.cpp
@@ -39,7 +39,7 @@
#include <krichtextlabel.h>
// other TQt headers:
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
#include <tqhbox.h>
@@ -112,10 +112,10 @@ BatteryConfig::BatteryConfig (TQWidget * parent, const char *name)
// group box to hold the icons together
TQVGroupBox* icons_groupbox = new TQVGroupBox( i18n("Select Battery Icons"), this );
- icons_groupbox->layout()->setSpacing( KDialog::spacingHint() );
+ icons_groupbox->tqlayout()->setSpacing( KDialog::spacingHint() );
top_layout->addWidget( icons_groupbox, 0, TQt::AlignLeft );
// layout to hold the icons inside the groupbox
TQGrid *icon_grid = new TQGrid( 3 /*cols*/, icons_groupbox );
icon_grid->setSpacing( KDialog::spacingHint() );
@@ -112,10 +112,10 @@ BatteryConfig::BatteryConfig (TQWidget * parent, const char *name)
top_layout->addWidget( icons_groupbox, 0, TQt::AlignLeft );
- // layout to hold the icons inside the groupbox
+ // tqlayout to hold the icons inside the groupbox
TQGrid *icon_grid = new TQGrid( 3 /*cols*/, icons_groupbox );
icon_grid->setSpacing( KDialog::spacingHint() );